pub struct CommandContext {
pub(crate) app: AppContext,
pub(crate) ui: UiSettings,
}Fields
app: AppContextui: UiSettingsImplementations
Sourceimpl CommandContext
impl CommandContext
Sourcepub fn from_config(config: &Config) -> Result<Self>
pub fn from_config(config: &Config) -> Result<Self>
Build a command context from a loaded configuration.
Sourcepub fn from_config_with_verbosity(
config: &Config,
verbosity: u8,
) -> Result<Self>
pub fn from_config_with_verbosity( config: &Config, verbosity: u8, ) -> Result<Self>
Build a command context with an explicit verbosity level.
Sourcepub fn app(&self) -> &AppContext
pub fn app(&self) -> &AppContext
Return the application context used by the command handlers.